==> linuxconf-1.30r2.src.tar.gz: linuxconf-1.30r2/tlmp/tlmplib/tlmplib.pm <==
/* copyfile.cc 08/09/2001 23.06.08 */
void _F_copyfile::fail (const char *src,
	 const char *dst,
	 const char *details);
void _F_copyfile::progress (const char *src,
	 const char *dst,
	 size_t size,
	 size_t sofar,
	 bool&end);
/* _dict.cc 20/02/1999 13.39.06 */
/* file.cc 29/04/2002 15.56.30 */
void _F_loadfile__v1::empty (const LOADFILE_INFO&);
void _F_loadfile__v1::start (const LOADFILE_INFO&);
void _F_loadfile__v1::end (off_t, const LOADFILE_INFO&);
void _F_loadfile__v1::missing (const char *fname);
void _F_savefile::start (FILE *, const char *);
void _F_savefile::end (FILE *, const char *);
void _F_savefile::openfail (const char *fname);
/* objectsub.cc 21/05/2002 22.31.38 */
PUBLIC OBJECTSUB::OBJECTSUB (_F_OBJECTSUB&_c);
PUBLIC void OBJECTSUB::exec (void);
/* sort.cc 02/08/2001 14.42.14 */
/* tlmplib.cc 20/02/1999 14.13.24 */
/* tlmpprogram.cc 01/01/2003 23.13.52 */
void _F_tlmpprogram___v0::setproginfo (const char *name,
	 const char *version,
	 const char *desc);
void _F_tlmpprogram___v0::setproginfo (const char *name,
	 int version,
	 int release,
	 const char *desc);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 const char *&val,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 SSTRING&val,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 SSTRINGS&vals,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 int &val,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 bool&val,
	 bool mandatory);
void _F_tlmpprogram___v1::usage (void);
void _F_tlmpprogram___v1::showerror (const char *msg);
int _F_tlmpprogram___v1::onearg (const char *, const char *);
int _F_tlmpprogram___v1::main_noarg (void);
void _F_tlmpprogram___v1::init (void);
/* walk.cc 09/05/2002 22.36.06 */
bool _F_walkfs::recurse (const char *,
	 const char *,
	 const char *,
	 int);
void _F_walkfs::end (void);
int _F_walkpopen::oneerr (const char *, const char *, FILE *);
void _F_walkpopen::start (FILE *, bool&);
void _F_walkpopen::end (void);
void _F_walkpopen::empty (const char *);
void _F_walkpopen::fail (const char *cmd);
void _F_walkpopen::close_input (void);
void _F_walkpopen::init (FILE *, bool&);
/* loadfile_v0.tlcc 31/01/2003 13.58.14 */
void _F_loadfile::empty (void);
void _F_loadfile::start (void);
void _F_loadfile::end (off_t);
void _F_loadfile::missing (const char *fname);
/* samples.tlcc 31/01/2003 13.58.14 */
/* streamp.tlcc 31/01/2003 13.58.14 */
PRIVATE void STREAMP_BUF::init (int size, int incr);
PUBLIC STREAMP_BUF::STREAMP_BUF (void);
PUBLIC STREAMP_BUF::STREAMP_BUF (int _bufsize, int incr);
PUBLIC STREAMP_BUF::~STREAMP_BUF (void);
PUBLIC void STREAMP_BUF::pack (bool force);
PUBLIC void STREAMP_BUF::pack (void);
PUBLIC bool STREAMP_BUF::isempty (void)const;
PUBLIC int STREAMP_BUF::getspace (void)const;
PUBLIC char *STREAMP_BUF::getinputbuf (void);
PUBLIC const char *STREAMP_BUF::getbytes (void);
PUBLIC int STREAMP_BUF::getnbbytes (void);
PUBLIC void STREAMP_BUF::setadded (int len);
PUBLIC void STREAMP_BUF::setused (int len);
PUBLIC void STREAMP_BUF::checkalloc (int len);
int _F_STREAMP::fill (void *buf, int size, bool&end);
int _F_STREAMP::process (const void *buf,
	 int len,
	 bool&end,
	 bool nomore);
int _F_STREAMP::validrecord (const void *buf,
	 int len,
	 bool&end,
	 bool nomore);
PUBLIC STREAMP::STREAMP (_F_STREAMP&c);
PUBLIC STREAMP::~STREAMP (void);
PRIVATE void STREAMP::pack (void);
PUBLIC void STREAMP::loop (void);
PUBLIC int STREAMP::fill (void *buf, int len);
PUBLIC void STREAMP::eof (void);
PUBLIC int STREAMP::getrecord (void *buf, int size);
/* tlmpprogram_v0.tlcc 31/01/2003 13.58.14 */
void _F_tlmpprogram::showerror (const char *msg);
int _F_tlmpprogram::onearg (const char *, const char *);
int _F_tlmpprogram::main_noarg (void);

==> linuxconf-1.33r2.src.tar.gz: linuxconf-1.33r2/tlmp/tlmplib/tlmplib.pm <==
/* copyfile.cc 08/09/2001 23.06.08 */
void _F_copyfile::fail (const char *src,
	 const char *dst,
	 const char *details);
void _F_copyfile::progress (const char *src,
	 const char *dst,
	 size_t size,
	 size_t sofar,
	 bool&end);
/* _dict.cc 20/02/1999 13.39.06 */
/* file.cc 29/04/2002 15.56.30 */
void _F_loadfile__v1::empty (const LOADFILE_INFO&);
void _F_loadfile__v1::start (const LOADFILE_INFO&);
void _F_loadfile__v1::end (off_t, const LOADFILE_INFO&);
void _F_loadfile__v1::missing (const char *fname);
void _F_savefile::start (FILE *, const char *);
void _F_savefile::end (FILE *, const char *);
void _F_savefile::openfail (const char *fname);
/* objectsub.cc 21/05/2002 22.31.38 */
PUBLIC OBJECTSUB::OBJECTSUB (_F_OBJECTSUB&_c);
PUBLIC void OBJECTSUB::exec (void);
/* sort.cc 02/08/2001 14.42.14 */
/* tlmplib.cc 20/02/1999 14.13.24 */
/* tlmpprogram.cc 01/01/2003 23.13.52 */
void _F_tlmpprogram___v0::setproginfo (const char *name,
	 const char *version,
	 const char *desc);
void _F_tlmpprogram___v0::setproginfo (const char *name,
	 int version,
	 int release,
	 const char *desc);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 const char *&val,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 SSTRING&val,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 SSTRINGS&vals,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 int &val,
	 bool mandatory);
void _F_tlmpprogram___v0::setarg (const char letter,
	 const char *name,
	 const char *desc,
	 bool&val,
	 bool mandatory);
void _F_tlmpprogram___v1::usage (void);
void _F_tlmpprogram___v1::showerror (const char *msg);
int _F_tlmpprogram___v1::onearg (const char *, const char *);
int _F_tlmpprogram___v1::main_noarg (void);
void _F_tlmpprogram___v1::init (void);
/* walk.cc 14/03/2003 14.53.12 */
bool _F_walkfs::recurse (const char *,
	 const char *,
	 const char *,
	 int);
void _F_walkfs::end (void);
int _F_walkpopen__v1::wait (POPEN&pop, int timeout, bool&end);
int _F_walkpopen__v1::oneerr (const char *, const char *, FILE *);
void _F_walkpopen__v1::start (FILE *, bool&);
void _F_walkpopen__v1::end (void);
void _F_walkpopen__v1::empty (const char *);
void _F_walkpopen__v1::fail (const char *cmd);
void _F_walkpopen__v1::close_input (void);
void _F_walkpopen__v1::init (FILE *, bool&);
/* loadfile_v0.tlcc 14/03/2003 14.53.14 */
void _F_loadfile::empty (void);
void _F_loadfile::start (void);
void _F_loadfile::end (off_t);
void _F_loadfile::missing (const char *fname);
/* samples.tlcc 14/03/2003 14.53.14 */
/* streamp.tlcc 14/03/2003 14.53.14 */
PRIVATE void STREAMP_BUF::init (int size, int incr);
PUBLIC STREAMP_BUF::STREAMP_BUF (void);
PUBLIC STREAMP_BUF::STREAMP_BUF (int _bufsize, int incr);
PUBLIC STREAMP_BUF::~STREAMP_BUF (void);
PUBLIC void STREAMP_BUF::pack (bool force);
PUBLIC void STREAMP_BUF::pack (void);
PUBLIC void STREAMP_BUF::reset (void);
PUBLIC bool STREAMP_BUF::isempty (void)const;
PUBLIC int STREAMP_BUF::getspace (void)const;
PUBLIC char *STREAMP_BUF::getinputbuf (void);
PUBLIC const char *STREAMP_BUF::getbytes (void);
PUBLIC int STREAMP_BUF::getnbbytes (void);
PUBLIC void STREAMP_BUF::setadded (int len);
PUBLIC void STREAMP_BUF::setused (int len);
PUBLIC void STREAMP_BUF::checkalloc (int len);
int _F_STREAMP::fill (void *buf, int size, bool&end);
int _F_STREAMP::process (const void *buf,
	 int len,
	 bool&end,
	 bool nomore);
int _F_STREAMP::validrecord (const void *buf,
	 int len,
	 bool&end,
	 bool nomore);
PUBLIC STREAMP::STREAMP (_F_STREAMP&c);
PUBLIC STREAMP::~STREAMP (void);
PRIVATE void STREAMP::pack (void);
PUBLIC void STREAMP::loop (void);
PUBLIC int STREAMP::fill (void *buf, int len);
void _F_STREAMP::reset (void);
PUBLIC void STREAMP::eof (void);
PUBLIC int STREAMP::getrecord (void *buf, int size);
void _F_streamp::reset (void);
void _F_streamp_do::reset (void);
/* tlmpprogram_v0.tlcc 14/03/2003 14.53.14 */
void _F_tlmpprogram::showerror (const char *msg);
int _F_tlmpprogram::onearg (const char *, const char *);
int _F_tlmpprogram::main_noarg (void);
/* walkpopen_v0.tlcc 14/03/2003 14.53.14 */
void _F_walkpopen::close_input (void);
